| Safe Haskell | None |
|---|---|
| Language | GHC2021 |
Bluesky.Did
Documentation
A DID is a Decentralized Identifier. They're codified by various W3C standards. This type only aims to capture how they are used in atproto.
Constructors
| NoDidPrefix | |
| NoMethodSeparator | after "did:", there must be another colon to delimit method from identifier |
| BadMethod | method must match the regex |
| BadIdentifierCharacters | identifier section must match |
| EndsWithColon | |
| BadPercentEncoding | the spec says implementations don't need to validate percent encoding, but we validate that every % is followed by two hex digits |
Fields that the library currently doesn't understand are ignored.
getDocument :: HasCallStack => Manager -> Did -> IO (Maybe Document) Source #
This is currently only implemented for did:plc: DIDs.